@@ -65,24 +65,7 @@ static int rpg_fdnom = 0;
 struct rlimit fdlim;
 static int flag = 0;
 
-void revcpy(char * from , char * to , int size){
-	int cnt;
-	for (cnt=0;cnt<size;cnt++)
-		to[size-cnt-1]=from[cnt];
-}
-int revint(char * from){
-	int ret;
-	int n;
-	n=1;
-	if( *(char*)&n ){
-		revcpy (from , (char *)&ret , sizeof(int));
-	}else{
-		ret = *from;
-	}
-	return ret;
-}
 
-/*komment*/
 void brakepipe(int data){
 	rpglog (RPGDEBUGLEVEL ,"libnet:get broken pipe\n");
 	/*ïΥʥ뤫Ϥ狼ʤҤȤޤfʤˤ⤷ʤ*/
@@ -94,11 +77,13 @@ void brakepipe(int data){
 
 void  rpg_childdeth(int data){
 struct rusage rusage;
+int status;
 	rpglog(RPGDEBUGLEVEL , "libnet:Is child prosess die?\n");
-	wait3(NULL, WNOHANG,&rusage);	/*ҥץ򤫤ƥӤˤʤʤ褦ˤ*/
-	if (signal (SIGCHLD , rpg_childdeth) == SIG_ERR){/*ʥľ*/
-		rpglog ( RPGDEBUGLEVEL , "libnet:Set signal error\n");
-		exit (1);
+	while (waitpid (-1,&status,WNOHANG)>0){
+		if (signal (SIGCHLD , rpg_childdeth) == SIG_ERR){/*ʥľ*/
+			rpglog ( RPGDEBUGLEVEL , "libnet:Set signal error\n");
+			exit (1);
+		}
 	}
 	return ;
 }
@@ -218,6 +203,25 @@ int cnt;
 
 }
 
+/*ƤΣƣĤ򥯥
+ơǡ١⥯ꥢ
+Ƴݤ*/
+
+void rpg_fd_allclosewithout(int FD){
+int cnt;
+	for (cnt = 0 ; cnt < fdlim.rlim_cur ; cnt ++){
+		if (rpg_FDS[cnt] == FD)continue;
+		if (rpg_FDS[cnt] != 0){
+			close (rpg_FDS[cnt]);
+			rpg_FDS[cnt] = ( int )NULL;
+			rpg_IDS[cnt] = ( int )NULL;
+			rpg_IDSR[cnt] = ( int )NULL;
+			rpg_UDPAD[cnt].sin_family = (int)NULL;
+			rpg_UDPAD[cnt].sin_port = (int)NULL;
+		}
+	}
+}
+
 /*ǡ١
 ǽΰ󤷤򤷤ʤΤǤޤäˤˤ
 rpg_fd_allcloseȤɬפ*/
@@ -765,22 +769,12 @@ libnet_send_st send_st;
 	if ((cnt = test_fd(FD))< 0)return LIBNETNOFDENT;
 	/*ѥåȤȤ*/
 	sprintf (send_st.head , LIBNETPHEADER);/*ңУǥѥåȤǤ뤳Ȥ򼨤ʸ򤤤*/
-	n=1;
-	if( *(char*)&n ){
-		int	tmp;
-		tmp=getpid();
-		revcpy ((char *)&tmp , (char *)&send_st.from_pid,sizeof(int));	/*ץΣɣ*/
-		tmp=rpg_IDS[cnt]++;		/*ɣġ꤬Ϣ³ǧ뤿*/
-		revcpy ((char *)&tmp , (char *)&send_st.ID,sizeof(int));
-		revcpy ((char *)&len,(char *)&send_st.length,sizeof(int));
-		send_st.status = 0;/*ơ*/
-	}else{
-	/*⤷ӥåǥ*/
-		send_st.from_pid = getpid();/*ץΣɣ*/
-		send_st.ID = rpg_IDS[cnt]++;/*ɣġ꤬Ϣ³ǧ뤿*/
-		send_st.length = len;/*ǡĹ*/
-		send_st.status = 0;/*ơ*/
-	}
+	/*ץΣɣ*/
+	send_st.from_pid=htonl(getpid());
+	/*ɣġ꤬Ϣ³ǧ뤿*/
+	send_st.ID=htonl(rpg_IDS[cnt]++);
+	send_st.length=htonl(len);
+	send_st.status = 0;/*ơ*/
 	memset (send_st.command , 0 , COMMANDLEN);
 	memcpy (send_st.command , command , COMMANDLEN);
 	/*إåΰ*/
@@ -838,23 +832,11 @@ libnet_send_st send_st;
 	if ((cnt = test_fd(FD))< 0)return LIBNETNOFDENT;
 	/*ѥåȤȤ*/
 	sprintf (send_st.head , LIBNETPHEADER);/*ңУǥѥåȤǤ뤳Ȥ򼨤ʸ򤤤*/
-	/*⤷ȥ륨ǥ*/
-	n=1;
-	if( *(char*)&n ){
-		int	tmp;
-		tmp=getpid();
-		revcpy ((char *)&tmp , (char *)&send_st.from_pid,sizeof(int));	/*ץΣɣ*/
-		tmp=rpg_IDS[cnt]++;		/*ɣġ꤬Ϣ³ǧ뤿*/
-		revcpy ((char *)&tmp , (char *)&send_st.ID,sizeof(int));
-		revcpy ((char *)&len,(char *)&send_st.length,sizeof(int));
-		send_st.status = 0;/*ơ*/
-	}else{
-	/*⤷ӥåǥ*/
-		send_st.from_pid = getpid();/*ץΣɣ*/
-		send_st.ID = rpg_IDS[cnt]++;/*ɣġ꤬Ϣ³ǧ뤿*/
-		send_st.length = len;/*ǡĹ*/
-		send_st.status = 0;/*ơ*/
-	}
+	send_st.from_pid=htonl(getpid());
+	/*ɣġ꤬Ϣ³ǧ뤿*/
+	send_st.ID=htonl(rpg_IDS[cnt]++);
+	send_st.length=htonl(len);
+	send_st.status = 0;/*ơ*/
 	
 	memset (send_st.command , 0 , COMMANDLEN);
 	memcpy (send_st.command , command , COMMANDLEN);
@@ -1157,7 +1139,7 @@ int RPG_Poll( char * command , char * data , int buf_length , int *length , int
 					return LIBNETHEADSENDERR;
 				}
 				/*׵Ĺ*/
-				requestlen = revint((char*)&packet_head.length);
+				requestlen = ntohl(packet_head.length);
 				if (requestlen <= 0){
 					/*ͤλϥ顼֤*/
 					return LIBNETNOREQLEN;
@@ -1171,11 +1153,11 @@ int RPG_Poll( char * command , char * data , int buf_length , int *length , int
 					return LIBNETERROTHER;
 				}
 				/*ɣĤäȤϥơ˿ä*/
-				if (++rpg_IDSR[cnt2] != revint((char*)&packet_head.ID)){
+				if (++rpg_IDSR[cnt2] != ntohl(packet_head.ID)){
 					stat = LIBNETNOIDCONTINU;
 					rpglog (RPGDEBUGLEVEL , "libnet:The ID was fault[%d]-[%d]\n" , 
-						rpg_IDSR[cnt2] ,revint((char*)&packet_head.ID));
-					rpg_IDSR[cnt2] = revint((char*)&packet_head.ID);
+						rpg_IDSR[cnt2] ,ntohl(packet_head.ID));
+					rpg_IDSR[cnt2] = ntohl(packet_head.ID);
 				}
 				memcpy (command	 ,packet_head.command , COMMANDLEN );
 				/*ѥåȤɤ߹*/
@@ -1478,13 +1460,7 @@ va_list ap;
 	}
 	n=1;
 	/*ФФ򤹤*/
-	if( *(char*)&n ){
-		/*⡼륨ǥ*/
-		revcpy ((char *)&DBlev , (char *)filename,sizeof(int));	/*ץΣɣ*/
-	}else{
-		/*⤷ӥåǥ*/
-		memcpy (filename ,(char *)&DBlev , sizeof (int));
-	}
+	*((int *)filename)=htonl(DBlev);
 	if (rpglogfd > 0){
 #if 0
 		strncpy (&filename[sizeof (int)] , errerbufffer , strlen (errerbufffer));
@@ -1616,7 +1592,7 @@ char *	RPG_shmctl_init(shment * shmentry , int entrynom  , int *ctlshmid ){
 		ret3 = RPG_shmctl_addentry( shmentry[cnt].shmNO, shmentry[cnt].size );
 		if ((int)(ret3) < (int)NULL){
 			char * buf = NULL;
-			rpglog (RPGDEBUGLEVEL , "libnet:shmaddentry error [%d] [%s]\n" , ret3 ,(char *) rpg_net_perror((int)ret3 , buf));
+			rpglog (RPGDEBUGLEVEL , "libnet:shmaddentry error [%d] [%s]\n" , ret3 ,(char *) rpg_net_perror((int)ret3 , &buf));
 			PRG_shmctl_destroy();
 			return (ret3);
 		}else{
@@ -1766,7 +1742,7 @@ char * rpg_mopen(char * filepath );
 
 void rpg_memclose (char *filepath );
 **********************************************************/
-libnet_mmaps libnet_mmap[MAXMEMNOM];
+static libnet_mmaps libnet_mmap[MAXMEMNOM];
 
 static int rpgmmatnom = 0;
 char * rpg_mopen(char * filepath ){
@@ -2054,7 +2030,7 @@ errtable errmessage[MAXERRNOM] = {
 
 
 
-char *rpg_net_perror(int l_errno ,char * message){
+char *rpg_net_perror(int l_errno ,char ** message){
 char *ret = NULL;
 int cnt;
 
