@@ -1161,13 +1161,13 @@ int rpg_gethash ( unsigned short * data , int len);
 
 	
 		int l_errno			I	Υ顼å
-		char * message		O	å
+		char ** message		O	åƤؤΥݥ󥿤֤
 
 	͡
 		char *	顼åΥȥ֤
 
 */
-char *rpg_net_perror(int l_errno ,char * message);
+char *rpg_net_perror(int l_errno ,char ** message);
 /**************************************************************************/
 
 #endif	/*LIBNET_H*/
